The StorageTopology library is a library supporting research within the work "Storage Latency Tradeoffs in Geographically Distributed Storage Settings".  This work is an undergraduate honors thesis written by Ethan Balcik of the Pennsylvania State University, who was advised by Viveck R. Cadambe, associate professor of electrical engineering.  The work explores the application of erasure coding in distributed data stores (such as Amazon DynamoDB, Apache Cassandra, and/or Google Spanner).  Particularly, it investigates the effects erasure coding has on latency in comparison to replication, and it explores the cases in which erasure coding counterintuitively outperforms replication.  A link to the work will soon be available to those interested in reading more about the nature of the research.

To install using pip, simply run the command,
```pip install StorageTopology --upgrade```

To contribute to the library, fork the below repository and feel free to send a pull request to the owner of the repository.
https://github.com/whatsacomputertho/StorageTopology